PCB Environment: UIApplication Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
UIApplication Class Reference
Inheritance diagram for UIApplication:

## Public Member Functions
Agent * | getUserAgent () const
| These are not available outside the UI as it wouldn't be thread-safe.
Agent * | getAutoAgent () const
PCBoard * | getPCB () const
Public Member Functions inherited from IUIApplication
virtual std::future< bool > | runAsync ()
virtual void | show ()
virtual void | hide ()
virtual void | wait ()
virtual void | quit (int code)
virtual void | setPCB (const std::shared_ptr< PCBoard > &, bool wait=true)
virtual void | setAutonomousAgent (const std::shared_ptr< Agent > &, const std::shared_ptr< PCBoard > &)
void | startExclusiveTask (const char *warn=0)
bool | tryStartExclusiveTask (const char *name=0)
bool | endExclusiveTask (bool rv=true, const char *reason=0)

## Additional Inherited Members
Static Public Member Functions inherited from IUIApplication
static IUIApplication * | create ()
Protected Attributes inherited from IUIApplication
std::shared_ptr< PCBoard > | mPCB
std::unique_ptr< Agent > | mUserAgent
std::shared_ptr< Agent > | mAutoAgent

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/Application.hpp